pub fn run_build(dir: &Path, started: Instant) -> BuildResultExpand description
Run a release wasm build of the project directory synchronously.
Used by the headless pixel8 build/export subcommands.
pub fn run_build(dir: &Path, started: Instant) -> BuildResultRun a release wasm build of the project directory synchronously.
Used by the headless pixel8 build/export subcommands.