pub fn blit(fb: &mut Framebuffer, x0: i32, y0: i32, rows: &[&str])Expand description
Paint a pixel grid (one hex palette index per cell; . = black/0; 5 = the
dark-grey editor background, treated as transparent so it shows through).
pub fn blit(fb: &mut Framebuffer, x0: i32, y0: i32, rows: &[&str])Paint a pixel grid (one hex palette index per cell; . = black/0; 5 = the
dark-grey editor background, treated as transparent so it shows through).